@@ -1,5 +1,6 @@
 import redis
 from os import getenv
+from time import sleep
 
 
 class RedisDB:
@@ -17,4 +18,14 @@ class RedisDB:
             self.redis = redis.Redis(host=self.__redis_host, password=self.__redis_password, port=self.__redis_port)
 
         except Exception as ex:
-            print(ex)
+            print(ex, flush=True)
+            self.__reconect()
+
+    def __reconect(self):
+        try:
+            if not self.redis:
+                self.__connect()
+
+        except Exception:
+            sleep(3)
+            self.__reconect()
